@@ -30,7 +30,7 @@
 #include <KMime/Message>
 #include <Akonadi/KMime/MessageStatus>
 
-class EmailIndexer: public AbstractIndexer
+class EmailIndexer : public AbstractIndexer
 {
 public:
     /**
@@ -43,13 +43,10 @@ public:
     QStringList mimeTypes() const override;
 
     void index(const Akonadi::Item &item) override;
-    void updateFlags(const Akonadi::Item &item, const QSet<QByteArray> &added,
-                     const QSet<QByteArray> &removed) override;
+    void updateFlags(const Akonadi::Item &item, const QSet<QByteArray> &added, const QSet<QByteArray> &removed) override;
     void remove(const Akonadi::Item &item) override;
     void remove(const Akonadi::Collection &item) override;
-    void move(Akonadi::Item::Id itemId,
-              Akonadi::Collection::Id from,
-              Akonadi::Collection::Id to) override;
+    void move(Akonadi::Item::Id itemId, Akonadi::Collection::Id from, Akonadi::Collection::Id to) override;
 
     void commit() override;
 
@@ -64,7 +61,7 @@ private:
 
     void process(const KMime::Message::Ptr &msg);
     void processPart(KMime::Content *content, KMime::Content *mainContent);
-    void processMessageStatus(const Akonadi::MessageStatus &status);
+    void processMessageStatus(Akonadi::MessageStatus status);
 
     void insert(const QByteArray &key, KMime::Headers::Base *base);
     void insert(const QByteArray &key, KMime::Headers::Generics::MailboxList *mlist);
